
# q-expansion of newform 1078.2.c.c, downloaded from the LMFDB on 10 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1078
weight = 2
poly_data = [1048576, 0, 1310720, 0, 819200, 0, 72448, 0, -1087, 0, -2272, 0, 512, 0, -32, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-481919500288, 0, 1011889152, 0, 474538112, 0, -133787245, 0, -46669984, 0, -6919680, 0, 668960, 0, -32173, 0], 341451177984], [[115772308922368, 0, 35129391631360, 0, 4403763700640, 0, -905783138901, 0, 73242356320, 0, 4404178432, 0, -500615872, 0, 21649515, 0], 28937987334144], [[167526400000, 0, 194978259968, 0, 13417758552, 0, 491616713, 0, -662732768, 0, 129966848, 0, -7913160, 0, 240905, 0], 149937758208], [[30704009216, 0, 35772670976, 0, 2634257152, 0, 119589033, 0, -119264224, 0, 23098880, 0, -1400096, 0, 42729, 0], 19295207424], [[0, 298669982056448, 0, 114707998022656, 0, 10664594701728, 0, -1703395919255, 0, -28654574560, 0, 46096726528, 0, -3358638720, 0, 116266153], 308671864897536], [[8620523487232, 0, -11825933968384, 0, -2009136336864, 0, -267579354193, 0, 111831131872, 0, -16598608384, 0, 933827904, 0, -26548369, 0], 9645995778048], [[849802264576, 0, 743042069504, 0, 101561457888, 0, -5141852845, 0, -2062231712, 0, 519454208, 0, -33066624, 0, 1040915, 0], 256088383488], [[-49543323222016, 0, -84320719473664, 0, -12255806975456, 0, -107080965789, 0, 410096159072, 0, -76278327808, 0, 4561306816, 0, -135220701, 0], 28937987334144], [[0, -723250826477568, 0, -279805449960448, 0, -27621977981728, 0, 3864561461317, 0, 66556609440, 0, -104813186560, 0, 7568932160, 0, -263077499], 308671864897536], [[0, -13167578624000, 0, 13433955225472, 0, 997736067176, 0, 42003795807, 0, -45705450272, 0, 8514025600, 0, -510774904, 0, 15339039], 14468993667072], [[0, 289533980278784, 0, 107128611381248, 0, 7821020117440, 0, 381384242511, 0, -349822477600, 0, 70457976320, 0, -4312976672, 0, 133618959], 115751949336576], [[0, -4233948004352, 0, -7459200822272, 0, -851122418272, 0, -17555552883, 0, 30984053920, 0, -5954700800, 0, 359824640, 0, -10897203], 8194828271616], [[0, 34935425286144, 0, 64498714624768, 0, 4585099534888, 0, 178889617223, 0, -219318324768, 0, 42111652864, 0, -2548789688, 0, 77172743], 28937987334144], [[0, -303112411742208, 0, -257651828076544, 0, -18179529719584, 0, -760912344947, 0, 861452174496, 0, -170792382976, 0, 10421936192, 0, -319597619], 115751949336576], [[0, -10214744358912, 0, -17995089961984, 0, -2043398985376, 0, -37801257875, 0, 75544371360, 0, -14336292352, 0, 863194304, 0, -25933907], 8194828271616]]

hecke_ring_character_values = [[199, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [981, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, -1, 1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -2, -1, -1, -2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, -3], [-1, -1, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, -1, -4, 0, 0, 1, -1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, -2, -1, 1, 0, 0, -1, 0], [-5, 2, 1, 0, 0, 0, 1, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 0], [1, 0, -1, 2, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0], [2, -1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 3, 0, 0, 0, 0, -1, 0, 0, 0, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 5, -2, 1, -1], [1, 3, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-3, -5, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 1, 2, -2], [0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 1, -2, -1], [0, 0, 0, 0, 0, 4, 0, 0, 0, 1, 1, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3, -2, -1, 1], [0, 0, 0, 0, 0, -3, 0, 0, 0, -4, 1, 1, 0, 0, 1, 0], [0, 0, 0, -6, 4, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [6, -2, 2, 0, 0, 0, 2, -1, -1, 0, 0, 0, 0, 0, 0, 0], [-3, 0, 3, 6, 2, 0, -3, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -7, 1, 1, -1], [3, 0, -1, 0, 0, 0, -1, 2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -3, -1, 1, 5], [-3, 0, 3, 0, 4, 0, -3, -1, 1, 0, 0, 0, 0, 0, 0, 0], [1, 0, -1, 14, 0, 0, 1, -1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 4, 0, 0, 0, -3, 0, -3, 0, 0, 0, 0], [3, 5, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 6], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, -1, -11], [5, -4, 1, 0, 0, 0, 1, 3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, -2, -3, -1, 0, 0, -3, 0], [0, 6, -4, 0, 0, 0, -4, 2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 6, 2, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 2, -10, -2, 0, -2, -2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -7, 2, 1, 0, 0, 2, 0], [1, 0, -1, -10, 4, 0, 1, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, 4, -1, -1, 0, 0, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 11, 3, -1, 1], [0, 0, 0, 0, 0, -7, 0, 0, 0, 4, 3, 1, 0, 0, 3, 0], [-1, 0, 1, 4, 10, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 1, 10, -8, 0, -1, 3, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, -4, -3, 2, 10], [0, 0, 0, 0, 0, 4, 0, 0, 0, -5, 1, 2, 0, 0, 1, 0], [0, 0, 0, 0, 0, -9, 0, 0, 0, -6, 1, -2, 0, 0, 1, 0], [0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 0, 0, 7, 4, 1, 0, 0, 4, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, -2, -2, 8], [-1, 0, 1, -8, -6, 0, -1, 1, -1, 0, 0, 0, 0, 0, 0, 0], [3, 0, -3, 12, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -11, 1, 0, -3], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 4, 1, 11], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, -3, -1, -5], [0, 0, 0, 0, 0, -5, 0, 0, 0, 4, 3, 1, 0, 0, 3, 0], [0, 0, 0, 0, 0, 6, 0, 0, 0, -5, 1, 2, 0, 0, 1, 0], [8, -8, -2, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [6, -12, 0, 0, 0, 0, 0, -3, -3, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 2, 2, 12, 0, -2, 2, -2, 0, 0, 0, 0, 0, 0, 0], [-3, 0, 3, -6, -2, 0, -3, -4, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, -1, -11], [0, 0, 0, 0, 0, 7, 0, 0, 0, -4, -4, -4, 0, 0, -4, 0], [-1, 0, 1, -14, 4, 0, -1, -3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 7, 0, 0, 0, 2, 1, 3, 0, 0, 1, 0], [0, 0, 0, 6, -8, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0], [-9, -1, 5, 0, 0, 0, 5, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 13, 0, 0, 0, 12, -1, 1, 0, 0, -1, 0], [0, 17, -2, 0, 0, 0, -2, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 5, 0, 0, 0, 2, 3, -5, 0, 0, 3, 0], [-13, -3, 1, 0, 0, 0, 1, -2, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 4, 1, 3, 0], [0, 0, 0, 0, 0, 7, 0, 0, 0, 4, 3, -6, 0, 0, 3, 0], [-10, -7, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 1, -14, -16, 0, -1, -1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -13, 0, 0, 0, 4, 5, 0, 0, 0, 5, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, -4, 0, 2, -8], [-4, 12, -2, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [6, 1, 2, 0, 0, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0], [4, 0, -4, 14, 4, 0, 4, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 7, 4, 3, -3], [-5, 9, -1, 0, 0, 0, -1, -6, -6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 4, 0, 0, 0, 15, -2, 0, 0, 0, -2, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 10, -4, 2, 4], [7, 7, -5, 0, 0, 0, -5, -4, -4, 0, 0, 0, 0, 0, 0, 0], [-4, 0, 4, 4, 12, 0, -4, 4, -4, 0, 0, 0, 0, 0, 0, 0], [5, 5, 3, 0, 0, 0, 3, 2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, -6, -12], [0, 0, 0, 0, 0, 8, 0, 0, 0, 1, 4, 1, 0, 0, 4, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -17, 0, -2, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -11, 3, 1, 11], [2, 0, -2, -2, 4, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-6, 0, 6, 12, 2, 0, -6, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 6, 0, 0, 0, 6, -6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, -3, -1, -5], [-4, 0, 4, 10, -10, 0, -4, 2, -2, 0, 0, 0, 0, 0, 0, 0], [2, 0, -2, 16, 8, 0, 2, -1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 7, 0, 0, 0, 12, -3, -2, 0, 0, -3, 0], [0, 0, 0, 0, 0, 4, 0, 0, 0, 11, -1, -4, 0, 0, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 0, 8, -1, 6, 6], [-3, -1, 1, 0, 0, 0, 1, 2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -16, -3, -1, 4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 10, 2, 2, 4], [3, 0, -3, 0, -6, 0, 3, 3, -3, 0, 0, 0, 0, 0, 0, 0], [17, 6, 7, 0, 0, 0, 7, 3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 3, 0, 0, 0, -14, 0, 6, 0, 0, 0, 0], [3, 0, 3, 0, 0, 0, 3, -3, -3, 0, 0, 0, 0, 0, 0, 0], [-5, 2, 3, 0, 0, 0, 3, -5, -5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 0, 0, -9, -3, 6, 0, 0, -3, 0], [0, 0, 0, 0, 0, -10, 0, 0, 0, 5, 2, 3, 0, 0, 2, 0], [20, -7, 2, 0, 0, 0, 2, -3, -3, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 1, 10, -8, 0, -1, -6, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 7, 0, 0, 0, 10, 1, -5, 0, 0, 1, 0], [3, 0, -3, 0, 6, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, -1, 8, -3, -3], [5, 4, -5, 0, 0, 0, -5, 3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 16, 0, 0, 0, -1, -5, 0, 0, 0, -5, 0], [4, 0, -4, 2, 2, 0, 4, 6, -6, 0, 0, 0, 0, 0, 0, 0], [-4, -1, -2, 0, 0, 0, -2, -3, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 0, 0, 13, 4, -1, 0, 0, 4, 0], [0, 0, 0, 0, 0, -10, 0, 0, 0, 3, 2, 5, 0, 0, 2, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 11, -4, -3, 3], [2, 0, -2, -20, -2, 0, 2, -3, 3, 0, 0, 0, 0, 0, 0, 0], [-3, 0, 3, -6, 16, 0, -3, -1, 1, 0, 0, 0, 0, 0, 0, 0], [-7, 5, -3, 0, 0, 0, -3, -4, -4, 0, 0, 0, 0, 0, 0, 0], [10, -5, 0, 0, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -4, -3, -1, 4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 12, -1, -2, -4], [0, 0, 0, 0, 0, 10, 0, 0, 0, -3, 2, 1, 0, 0, 2, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 17, 7, -2, -7], [0, 0, 0, 0, 0, -7, 0, 0, 0, 2, 3, -9, 0, 0, 3, 0], [-4, 0, 4, -14, 8, 0, -4, -1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 0, -1, -1, 6, -3], [7, 0, -7, -4, 0, 0, 7, -1, 1, 0, 0, 0, 0, 0, 0, 0], [1, -16, 1, 0, 0, 0, 1, 5, 5, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 1, -8, 26, 0, -1, -1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 11, 0, 0, 0, -4, 3, 1, 0, 0, 3, 0], [0, 0, 0, 0, 0, -12, 0, 0, 0, 15, 4, 3, 0, 0, 4, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 7, 8, -1, -23], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 9, 0, -12], [0, 0, 0, 0, 0, -18, 0, 0, 0, 1, -4, 2, 0, 0, -4, 0], [22, -10, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 2, -22, -14, 0, -2, -2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 9, 0, 0, 0, -6, -1, 8, 0, 0, -1, 0], [15, 12, -5, 0, 0, 0, -5, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 14, 4, -2, 8], [10, 9, -2, 0, 0, 0, -2, -7, -7, 0, 0, 0, 0, 0, 0, 0], [-31, -9, -3, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 2, 20, 16, 0, -2, -2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 0, 0, -13, 6, 0, 0, 0, 6, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 24, -1, -2, 8], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, -8, -3, 9], [15, 0, 9, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, -1, -16, -14, 0, 1, -5, 5, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 1, 22, -10, 0, -1, 5, -5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 0, 0, -19, -4, -2, 0, 0, -4, 0], [4, 3, 0, 0, 0, 0, 0, -6, -6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, 2, -1, -13, 0, 0, -1, 0], [-15, 5, -3, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 3, 6, 3, -15], [-2, 0, 2, -22, 4, 0, -2, -5, 5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 3, 0, 0, 0, 4, -3, -5, 0, 0, -3, 0], [-1, 0, 1, -2, 18, 0, -1, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 0, 0, 9, 0, 11, 0, 0, 0, 0], [-6, 0, 6, 0, 8, 0, -6, 4, -4, 0, 0, 0, 0, 0, 0, 0], [5, 0, -5, -8, -2, 0, 5, -6, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -24, 0, 0, 0, -5, 0, 3, 0, 0, 0, 0], [0, 0, 0, 0, 0, 25, 0, 0, 0, -4, -1, 2, 0, 0, -1, 0], [1, 0, -1, 8, -6, 0, 1, 5, -5, 0, 0, 0, 0, 0, 0, 0], [13, -18, 3, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, -8, -10, 2, 22], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 11, 4, 1, 11], [-5, 14, 3, 0, 0, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -15, -1, -2, -19], [14, 15, -4, 0, 0, 0, -4, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, -14, 5, -4, 10], [-9, 2, -1, 0, 0, 0, -1, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -15, 0, 0, 0, 2, -3, -1, 0, 0, -3, 0], [4, 0, -4, 2, 6, 0, 4, 2, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -15, 0, 0, 0, 12, 1, -4, 0, 0, 1, 0], [1, 0, -1, 20, -10, 0, 1, 6, -6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, -4, 0, 2, 10], [0, 0, 0, 0, 0, -6, 0, 0, 0, -3, 2, -14, 0, 0, 2, 0], [9, 0, -9, -6, -2, 0, 9, -1, 1, 0, 0, 0, 0, 0, 0, 0], [-4, 9, -8, 0, 0, 0, -8, 3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -18, 0, 0, 0, -15, -4, 11, 0, 0, -4, 0], [7, 0, -7, -16, -16, 0, 7, -3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 10, 0, 0, 0, 13, -5, -6, 0, 0, -5, 0], [2, 0, -2, -2, 2, 0, 2, -4, 4, 0, 0, 0, 0, 0, 0, 0], [-4, 8, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 34, -5, 3, 6], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, -8, 2, 4], [-3, 0, 3, 12, 0, 0, -3, -3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 14, 6, 2, -2], [0, 0, 0, 0, 0, 13, 0, 0, 0, 18, 1, 1, 0, 0, 1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 14, 1, -5, -4], [0, 0, 0, 0, 0, -2, 0, 0, 0, -3, -7, 4, 0, 0, -7, 0], [0, 0, 0, 0, 0, -5, 0, 0, 0, 4, 3, 9, 0, 0, 3, 0], [0, 0, 0, 0, 0, -6, 0, 0, 0, -1, 6, -3, 0, 0, 6, 0], [8, 0, -8, 16, 6, 0, 8, 7, -7, 0, 0, 0, 0, 0, 0, 0], [-4, 0, 4, -14, -12, 0, -4, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 12, 0, 0, 0, -29, -7, -10, 0, 0, -7, 0], [-8, 0, 8, 14, 10, 0, -8, -2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, 4, -5, 3, 0, 0, -5, 0], [-18, -16, 2, 0, 0, 0, 2, 6, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -3, 0, 0, 0, 4, 9, 4, 0, 0, 9, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 6, 2, 4, -16], [0, 0, 0, 0, 0, -7, 0, 0, 0, -18, 3, 2, 0, 0, 3, 0], [2, 0, -2, 28, -24, 0, 2, -2, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 0, 6, 1, 5, -14], [-23, 3, -3, 0, 0, 0, -3, 6, 6, 0, 0, 0, 0, 0, 0, 0], [-16, -15, -2, 0, 0, 0, -2, 1, 1, 0, 0, 0, 0, 0, 0, 0], [7, 0, -7, -16, -6, 0, 7, 5, -5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 10, -2, -4], [-2, 3, 2, 0, 0, 0, 2, -1, -1, 0, 0, 0, 0, 0, 0, 0], [26, 0, -2, 0, 0, 0, -2, 4, 4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, -17, -5, -6, 9], [4, 0, -4, 14, 20, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 10, 0, 0, 0, -23, 1, 0, 0, 0, 1, 0], [-26, 8, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 0, 0, 6, 6, 6], [3, 0, -3, 6, -22, 0, 3, -2, 2, 0, 0, 0, 0, 0, 0, 0], [-4, -12, -2, 0, 0, 0, -2, -2, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 0, -23, -1, 5, -11], [8, 0, -8, 16, 4, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -12, -2, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 6, 0, 0, 0, -1, -8, -12, 0, 0, -8, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, -12, 4, 2, 16], [0, 0, 0, 0, 0, 9, 0, 0, 0, -14, -1, 0, 0, 0, -1, 0], [5, 0, -5, -8, 18, 0, 5, 1, -1, 0, 0, 0, 0, 0, 0, 0], [5, 15, 3, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 13, 0, 0, 0, -10, -1, 5, 0, 0, -1, 0], [-53, 1, 1, 0, 0, 0, 1, -3, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -27, -7, 1, 11], [0, 0, 0, 0, 0, 12, 0, 0, 0, -19, 0, 3, 0, 0, 0, 0], [0, -23, 2, 0, 0, 0, 2, -7, -7, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, -11, 0, 6], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 12, -10, -2, 8], [0, 0, 0, 0, 0, 4, 0, 0, 0, 5, 0, -13, 0, 0, 0, 0], [0, 0, 0, 0, 0, 16, 0, 0, 0, 13, -6, 4, 0, 0, -6, 0], [-12, 0, 12, 12, 16, 0, -12, 5, -5, 0, 0, 0, 0, 0, 0, 0], [-6, 0, 6, -36, 6, 0, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0], [10, 0, -10, 2, 4, 0, 10, 4, -4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 12, 5, -2, -34], [-23, -9, -3, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -10, 0, 0, 0, 3, -1, -4, 0, 0, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 11, 4, -5, -1], [-6, 0, 6, -42, -2, 0, -6, 2, -2, 0, 0, 0, 0, 0, 0, 0], [27, -6, 1, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -7, 0, 3, -13, 7, 5], [0, 0, 0, 0, 0, -10, 0, 0, 0, 25, 0, -3, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, -14, 9, 4, -22], [-5, 0, 5, 14, 8, 0, -5, 3, -3, 0, 0, 0, 0, 0, 0, 0], [2, 0, -2, 16, -20, 0, 2, -3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, -16, -1, 1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, -5, -4, -7, 19], [0, 0, 0, 0, 0, 6, 0, 0, 0, 19, 3, 4, 0, 0, 3, 0], [0, 0, 0, 0, 0, -8, 0, 0, 0, 3, 6, 10, 0, 0, 6, 0], [-10, -13, -4, 0, 0, 0, -4, 3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -20, 0, 0, 0, -19, -3, 4, 0, 0, -3, 0], [-5, 0, 5, 8, 0, 0, -5, 5, -5, 0, 0, 0, 0, 0, 0, 0], [3, 0, -3, 0, -14, 0, 3, 5, -5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -8, 0, 0, 0, 9, 0, 13, 0, 0, 0, 0], [-1, -33, -3, 0, 0, 0, -3, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 5, 0, 0, 0, -6, -6, 0, 0, 0, -6, 0], [3, 0, -3, 6, -40, 0, 3, 1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 34, -9, 4, -4], [0, 0, 0, 0, 0, -20, 0, 0, 0, 21, 4, 7, 0, 0, 4, 0], [10, -24, -4, 0, 0, 0, -4, 9, 9, 0, 0, 0, 0, 0, 0, 0], [-4, 0, 4, 10, 2, 0, -4, 8, -8, 0, 0, 0, 0, 0, 0, 0], [-4, 0, 4, 22, 22, 0, -4, 3, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, -9, -15, 3, 9], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, -14, 0, 6], [-21, -19, 3, 0, 0, 0, 3, 6, 6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, -16, 12, -4, -2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 0, 1, 8, 5, -35], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 33, -13, 4, 11], [-27, 5, 5, 0, 0, 0, 5, -6, -6, 0, 0, 0, 0, 0, 0, 0], [2, 35, -2, 0, 0, 0, -2, 3, 3, 0, 0, 0, 0, 0, 0, 0], [-9, 0, 9, -12, 16, 0, -9, 5, -5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 28, 0, 0, 0, -29, -2, -5, 0, 0, -2, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 28, -5, -3, 12], [-24, 7, 6, 0, 0, 0, 6, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 21, 0, 0, 0, -2, -8, 10, 0, 0, -8, 0], [1, 0, -1, 2, -14, 0, 1, -5, 5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 19, -5, 3, 15], [-5, 0, 5, -4, 24, 0, -5, -1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -7, 0, -7, -8, 7, 11], [0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, -11, 0, 0, 3, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, -30, -5, -1, 0, 0, -5, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, -5, 0, 27], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 3, 7, 2, -23], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -7, 0, -26, -3, 7, -4], [4, 0, -4, 26, 8, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 2, 32, -26, 0, -2, 4, -4, 0, 0, 0, 0, 0, 0, 0]]
